using System;
using System.Net.Mail;

namespace Palmmedia.Common
{
	/// <summary>
	/// Provides methods to send emails.
	/// </summary>
	public static class EmailHelper
	{
		/// <summary>
		/// Sends an email.
		/// </summary>
		/// <param name="sender">Email address of the sender.</param>
		/// <param name="recipient">Email address of the recipient.</param>
		/// <param name="replyto">Email adress to reply to (optional).</param>
		/// <param name="subject">Subject of the email.</param>
		/// <param name="body">Body of the email.</param>
		/// <exception cref="EmailException">Thrown if mail could not be send.</exception>
		public static void SendEmail(string sender, string recipient, string replyto, string subject, string body)
		{
			if (sender == null)
			{
				throw new ArgumentNullException("sender");
			}

			if (recipient == null)
			{
				throw new ArgumentNullException("recipient");
			}

			if (subject == null)
			{
				throw new ArgumentNullException("subject");
			}

			if (body == null)
			{
				throw new ArgumentNullException("body");
			}

			var message = new MailMessage(sender, recipient);

			if (!string.IsNullOrEmpty(replyto))
			{
				message.ReplyTo = new MailAddress(replyto);
			}

			message.From = new MailAddress(sender);
			message.Subject = subject;
			message.Body = body;

			try
			{
				var client = new SmtpClient();
				client.Send(message);
			}
			catch (SmtpException ex)
			{
				throw new EmailException("Sending Email failed.", ex);
			}
		}
	}
}
