﻿using System.Web.UI.WebControls;

namespace Palmmedia.Common.Linq
{
    /// <summary>
    /// Contains information necessary for paging and sorting.
    /// <seealso cref="PagingExtensions"/>.
    /// </summary>
    public class Paging
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="Paging" /> class.
        /// </summary>
        /// <param name="pageIndex">The current page index.</param>
        /// <param name="pageSize">Number of elements per page.</param>
        public Paging(int pageIndex, int pageSize)
        {
            this.SortDirection = SortDirection.Ascending;
            this.PageIndex = pageIndex;
            this.PageSize = pageSize;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Paging" /> class.
        /// </summary>
        /// <param name="pageIndex">The current page index.</param>
        /// <param name="pageSize">Number of elements per page.</param>
        /// <param name="sortColumn">The name of the property sorting should be applied to.</param>
        public Paging(int pageIndex, int pageSize, string sortColumn)
            : this(pageIndex, pageSize)
        {
            this.SortColumn = sortColumn;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="Paging" /> class.
        /// </summary>
        /// <param name="pageIndex">The current page index.</param>
        /// <param name="pageSize">Number of elements per page.</param>
        /// <param name="sortColumn">The name of the property sorting should be applied to.</param>
        /// <param name="sortDirection">The <see cref="SortDirection"/>.</param>
        public Paging(int pageIndex, int pageSize, string sortColumn, SortDirection sortDirection)
            : this(pageIndex, pageSize, sortColumn)
        {
            this.SortDirection = sortDirection;
        }

        /// <summary>
        /// Gets the <see cref="SortDirection"/>.
        /// </summary>
        internal SortDirection SortDirection { get; private set; }

        /// <summary>
        /// Gets he name of the property sorting should be applied to.
        /// </summary>
        internal string SortColumn { get; private set; }

        /// <summary>
        /// Gets the current page index.
        /// </summary>
        internal int PageIndex { get; private set; }

        /// <summary>
        /// Gets the number of elements per page.
        /// </summary>
        internal int PageSize { get; private set; }

        /// <summary>
        /// Returns a <see cref="System.String"/> that represents this instance.
        /// </summary>
        /// <returns>
        /// A <see cref="System.String"/> that represents this instance.
        /// </returns>
        public override string ToString()
        {
            return "SortColumn: " + this.SortColumn + ", PageIndex: " + this.PageIndex + ", PageSize: " + this.PageSize;
        }
    }
}
