﻿using System.Web.Mvc;
using System.Web.Routing;

namespace Palmmedia.Common.Net.Mvc
{
    /// <summary>
    /// Extends the <see cref="HtmlHelper"/> to create linked images.
    /// </summary>
    /// <example>
    /// <a href="..."><img src="..." alt="" /></a>
    /// </example>
    public static class ImageLinkExtensions
    {
        /// <summary>
        /// Creates an link with an image as content.
        /// </summary>
        /// <param name="helper">The <see cref="HtmlHelper"/>.</param>
        /// <param name="id">The id of the link.</param>
        /// <param name="controller">The controller.</param>
        /// <param name="action">The action of the controller.</param>
        /// <param name="querystring">The querystring.</param>
        /// <param name="imageUrl">The url of the image.</param>
        /// <param name="alternateText">The alternate text of the image.</param>
        /// <param name="style">The style of the image.</param>
        /// <returns>The link with an image as content.</returns>
        /// <remarks>Calling this method is equivalent to calling <see cref="ImageLink(System.Web.Mvc.HtmlHelper, string, string, string, string, string, string, string, object)"/> and passing <c>null</c> as parameter linkHtmlAttributes.</remarks>
        public static string ImageLink(
            this HtmlHelper helper, 
            string id, 
            string controller, 
            string action,
            string querystring, 
            string imageUrl, 
            string alternateText, 
            string style)
        {
            return ImageLink(helper, id, controller, action, querystring, imageUrl, alternateText, style, null);
        }

        /// <summary>
        /// Creates an link with an image as content.
        /// </summary>
        /// <param name="helper">The <see cref="HtmlHelper"/>.</param>
        /// <param name="id">The id of the link.</param>
        /// <param name="controller">The controller.</param>
        /// <param name="action">The action of the controller.</param>
        /// <param name="querystring">The querystring.</param>
        /// <param name="imageUrl">The url of the image.</param>
        /// <param name="alternateText">The alternate text of the image.</param>
        /// <param name="style">The style of the image.</param>
        /// <param name="linkHtmlAttributes">Furter attributes of the link.</param>
        /// <returns>The link with an image as content.</returns>
        public static string ImageLink(
            this HtmlHelper helper, 
            string id, 
            string controller, 
            string action, 
            string querystring, 
            string imageUrl, 
            string alternateText, 
            string style, 
            object linkHtmlAttributes)
        {
            var builder = new TagBuilder("a");

            builder.GenerateId(id);

            string target = string.Empty;

            if (!string.IsNullOrEmpty(controller))
            {
                target += "/" + controller;
            }

            if (!string.IsNullOrEmpty(action))
            {
                target += "/" + action;
            }

            builder.MergeAttribute("href", target + querystring);
			builder.InnerHtml = "<img src='" + imageUrl + "' alt='" + alternateText + "' title='" + alternateText + "' style=\"" + style + "\" />";
            builder.MergeAttributes(new RouteValueDictionary(linkHtmlAttributes));

            return builder.ToString(TagRenderMode.Normal);
        }
    }
}