using System.IO;
using System.Web.Mvc;

namespace Palmmedia.Common.Net.Mvc.Localization
{
    /// <summary>
    /// Extends the <see cref="WebFormView"/> to fix a bug in connection with RenderPartial.
    /// </summary>
    public class LocalizationWebFormView : WebFormView
    {
        /// <summary>
        /// The ViewPathKey.
        /// </summary>
        internal const string ViewPathKey = "__ViewPath__";

        /// <summary>
        /// Initializes a new instance of the <see cref="LocalizationWebFormView"/> class.
        /// </summary>
        /// <param name="viewPath">The view path.</param>
        public LocalizationWebFormView(string viewPath) : base(viewPath)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="LocalizationWebFormView"/> class.
        /// </summary>
        /// <param name="viewPath">The view path.</param>
        /// <param name="masterPath">The master path.</param>
        public LocalizationWebFormView(string viewPath, string masterPath) : base(viewPath, masterPath)
        {
        }

        /// <summary>
        /// Renders the specified view context.
        /// </summary>
        /// <param name="viewContext">The view context.</param>
        /// <param name="writer">The writer.</param>
        public override void Render(ViewContext viewContext, TextWriter writer)
        {
            // There seems to be a bug with RenderPartial tainting the page's view data,
            // so we should capture the current view path, and revert back after rendering.
            var originalViewPath = (string) viewContext.ViewData[ViewPathKey];
            
            viewContext.ViewData[ViewPathKey] = ViewPath;
            base.Render(viewContext, writer);
            
            viewContext.ViewData[ViewPathKey] = originalViewPath;
        }
    }
}