﻿using System;
using System.Security.Cryptography;
using System.Text;

namespace Palmmedia.Common
{
    /// <summary>
    /// Contains extension methods for processing <see cref="string">strings</see>.
    /// </summary>
    public static class StringExtensions
    {
        /// <summary>
        /// Shortens the given <see cref="string" />.
        /// </summary>
        /// <param name="value">The <see cref="string"/> to shorten.</param>
        /// <param name="maxlength">The maximum length of the <see cref="string"/>.</param>
        /// <returns>The shortened <see cref="string"/>.</returns>
        public static string Trim(this string value, int maxlength)
        {
            if (string.IsNullOrEmpty(value) || maxlength > value.Length)
            {
                return value;
            }

            return value.Substring(0, maxlength - 4) + " ...";
        }

        /// <summary>
        /// Returns <c>null</c> if <see cref="string"/> is empty otherwise the <see cref="string"/> itself.
        /// Gets the text or null if empty.
        /// </summary>
        /// <param name="value">The <see cref="string"/>.</param>
        /// <returns><c>null</c> if <see cref="string"/> is empty otherwise the <see cref="string"/> itself.</returns>
        public static string GetTextOrNullIfEmpty(this string value)
        {
            if (value == null || value.Trim().Length == 0)
            {
                return null;
            }

            return value;
        }

        /// <summary>
        /// Encrypts the given <see cref="string"/> with SHA1.
        /// </summary>
        /// <param name="value">The <see cref="string"/>.</param>
        /// <returns>The encrypted <see cref="string"/>.</returns>
        public static string EncryptSha1(this string value)
        {
            var hash = new SHA1CryptoServiceProvider().ComputeHash(Encoding.UTF8.GetBytes(value));
            return BitConverter.ToString(hash).Replace("-", string.Empty);
        }
    }
}
