﻿using System;
using System.Data.Objects;
using MVCBlog.Core.Repository;

namespace MVCBlog.Core.Database
{
    /// <summary>
    /// Inplementation of <see cref="IUnitOfWork"/> using Entity Framework.
    /// </summary>
    public sealed class EFUnitOfWork : IUnitOfWork, IDisposable
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="EFUnitOfWork" /> class.
        /// </summary>
        /// <param name="context">The <see cref="ObjectContext"/> to use.</param>
        public EFUnitOfWork(ObjectContext context)
        {
            if (context == null)
            {
                throw new ArgumentNullException("context");
            }

            this.Context = context;
        }

        /// <summary>
        /// Gets the <see cref="ObjectContext"/> to use.
        /// </summary>
        public ObjectContext Context { get; private set; }

        /// <summary>
        /// Commits the applied changes.
        /// </summary>
        public void Commit()
        {
            this.Context.SaveChanges();
        }

        /// <summary>
        /// Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
        /// </summary>
        public void Dispose()
        {
            if (this.Context != null)
            {
                this.Context.Dispose();
            }

            GC.SuppressFinalize(this);
        }
    }
}
