﻿using System;
using System.Configuration;
using System.IO;

namespace MVCBlog.Core.Entities
{
	/// <summary>
	/// Represents an Image.
	/// </summary>
	public partial class Image
	{
		/// <summary>
		/// Initializes a new instance of the <see cref="Image"/> class.
		/// </summary>
		public Image()
		{
			this.Id = Guid.NewGuid();
			this.Created = DateTime.Now;
		}

		/// <summary>
		/// Gets or sets the data.
		/// </summary>
		public byte[] Data
		{
			get
			{
                return File.ReadAllBytes(this.FullPath);
			}

			set
			{
                File.WriteAllBytes(this.FullPath, value);
			}
		}

        /// <summary>
        /// Gets the relative path.
        /// </summary>
        public string RelativePath
        {
            get
            {
                return ConfigurationManager.AppSettings["ImagesPath"] + this.Id.ToString() + "." + this.Extension;
            }
        }

        /// <summary>
        /// Gets the file path.
        /// </summary>
        private string FullPath
        {
            get
            {
                var applicationPath = System.Web.HttpContext.Current.Request.PhysicalApplicationPath;
                return Path.Combine(applicationPath, this.RelativePath);
            }
        }

		/// <summary>
		/// Deletes the corresponding file.
		/// </summary>
		internal void DeleteData()
		{
            File.Delete(this.FullPath);
		}
	}
}
