﻿using System.Threading;
using log4net;
using Palmmedia.Common.Ioc;

namespace MVCBlog.Core.Repository
{
    /// <summary>
    /// Manages the currently used instances of <see cref="IUnitOfWork"/>.
    /// </summary>
    public static class UnitOfWork
    {
        /// <summary>
        /// Logger instance.
        /// </summary>
        private static readonly ILog logger = LogManager.GetLogger(typeof(UnitOfWork));

        /// <summary>
        /// Gets the instance of <see cref="IUnitOfWork"/> depending on the current context.
        /// </summary>
        public static IUnitOfWork Current
        {
            get
            {
                return IocHelper.Resolve<IUnitOfWork>();
            }
        }

        /// <summary>
        /// Saves the made changes.
        /// </summary>
        public static void Commit()
        {
            var unitOfWork = IocHelper.Resolve<IUnitOfWork>();
            if (unitOfWork != null)
            {
                logger.Debug("Commiting UnitOfWork of Thread: " + Thread.CurrentThread.Name);
                unitOfWork.Commit();
            }
        }
    }
}
