﻿using System.Collections.Generic;
using MVCBlog.Core.Repository;
using Palmmedia.Common.Linq;

namespace MVCBlog.Core.Service
{
    /// <summary>
    /// Generic interface for accessing entities.
    /// </summary>
	/// <typeparam name="T">Class that derives from <see cref="System.Data.Objects.DataClasses.EntityObject"/>.</typeparam>
	public interface IGenericEntityService<T> where T : System.Data.Objects.DataClasses.EntityObject
    {
		/// <summary>
		/// Adds the given element to the <see cref="IGenericRepository{T}"/>.
		/// </summary>
		/// <param name="entity">The element to add.</param>
        void Add(T entity);

		/// <summary>
		/// Deletes the given element from the <see cref="IGenericRepository{T}"/>.
		/// </summary>
		/// <param name="entity">Das zu löschende Element.</param>
        void Delete(T entity);

		/// <summary>
		/// Updates the given element in the <see cref="IGenericRepository{T}"/>.
		/// </summary>
		/// <param name="entity">Das zu ändernde Element.</param>
        void Update(T entity);

		/// <summary>
		/// Returns an <see cref="IEnumerable{T}"/> from the <see cref="IGenericRepository{T}"/>.
		/// </summary>
		/// <returns>
		/// The <see cref="IEnumerable{T}"/> of all elements.
		/// </returns>
        IEnumerable<T> GetAll();

		/// <summary>
		/// Returns an <see cref="IEnumerable{T}"/> from the <see cref="IGenericRepository{T}"/>.
		/// </summary>
		/// <param name="paging">The <see cref="Paging"/>.</param>
		/// <param name="totalNumberOfElements">Total number of elements.</param>
		/// <returns>
		/// The <see cref="IEnumerable{T}"/> of all elements.
		/// </returns>
        IEnumerable<T> GetAll(Paging paging, out int totalNumberOfElements);
    }
}
