﻿using System;
using System.Collections.Generic;
using MVCBlog.Core.Entities;

namespace MVCBlog.Core.Service
{
    /// <summary>
	/// Access to <see cref="BlogEntryFile">BlogEntryFiles</see>.
    /// </summary>
	public class BlogEntryFileService : GenericEntityService<BlogEntryFile>, IBlogEntryFileService
    {
        /// <summary>
        /// Returns the <see cref="BlogEntryFile"/> with the given Id.
        /// </summary>
        /// <param name="id">The Id.</param>
        /// <returns>
        /// The <see cref="BlogEntryFile"/> with the given Id.
        /// </returns>
        public BlogEntryFile GetById(Guid id)
        {
            var file = this.Repository.SingleOrDefault(f => f.Id == id);
            return file;
        }

        /// <summary>
        /// Returns an <see cref="IEnumerable{T}"/> from the <see cref="MVCBlog.Core.Repository.IGenericRepository{T}"/>.
        /// </summary>
        /// <returns>
        /// The <see cref="IEnumerable{T}"/> of all elements.
        /// </returns>
        public override IEnumerable<BlogEntryFile> GetAll()
        {
            var files = base.GetAll();

            foreach (var file in files)
            {
                file.BlogEntryReference.Load();
            }

            return files;
        }

		/// <summary>
        /// Deletes the given element from the <see cref="MVCBlog.Core.Repository.IGenericRepository{T}"/>.
		/// </summary>
		/// <param name="entity">Das zu löschende Element.</param>
		public override void Delete(BlogEntryFile entity)
		{
			if (entity == null)
			{
				throw new ArgumentNullException("entity");
			}
			
			entity.DeleteData();
			base.Delete(entity);
		}
    }
}
