﻿using System;
using System.Collections.Generic;
using MVCBlog.Core.Entities;
using Palmmedia.Common.Linq;

namespace MVCBlog.Core.Service
{
    /// <summary>
	/// Interface for accessing <see cref="BlogEntry">BlogEntríes</see>.
    /// </summary>
	public interface IBlogEntryService : IGenericEntityService<BlogEntry>
    {
        /// <summary>
		/// Returns the <see cref="BlogEntry"/> with the given Id.
        /// </summary>
        /// <param name="id">The Id.</param>
		/// <returns>The <see cref="BlogEntry"/> with the given Id.</returns>
		BlogEntry GetById(Guid id);

        /// <summary>
		/// Returns the <see cref="BlogEntry"/> with the given header.
        /// </summary>
        /// <param name="includeInvisibleEntries">Determines whether invisible <see cref="BlogEntry">BlogEntries</see> should be included.</param>
        /// <param name="header">The header.</param>
        /// <returns>The <see cref="BlogEntry"/> with the given header.</returns>
        BlogEntry GetByHeader(bool includeInvisibleEntries, string header);

        /// <summary>
        /// Returns all <see cref="BlogEntry">BlogEntries</see>.
        /// </summary>
        /// <param name="includeInvisibleEntries">Determines whether invisible <see cref="BlogEntry">BlogEntries</see> should be included.</param>
        /// <param name="tag">The text of the tag.</param>
        /// <param name="search">The search.</param>
        /// <param name="paging">The <see cref="Paging"/>.</param>
        /// <param name="totalNumberOfElements">Total number of elements.</param>
        /// <returns>
        /// All <see cref="BlogEntry">BlogEntries</see>.
        /// </returns>
        IEnumerable<BlogEntry> GetAll(bool includeInvisibleEntries, string tag, string search, Paging paging, out int totalNumberOfElements);

        /// <summary>
        /// Returns related <see cref="BlogEntry">BlogEntries</see>.
        /// </summary>
        /// <param name="entry">The <see cref="BlogEntry"/>.</param>
        /// <param name="numberOfEntries">Maximum number of <see cref="BlogEntry">BlogEntries</see>.</param>
        /// <returns>The related <see cref="BlogEntry">BlogEntries</see>.</returns>
        IEnumerable<BlogEntry> GetRelatedBlogEntries(BlogEntry entry, int numberOfEntries);

		/// <summary>
		/// Adds the given <see cref="BlogEntry"/>.
		/// </summary>
		/// <param name="entry">The <see cref="BlogEntry"/> to add.</param>
		/// <param name="tags">The tags.</param>
		void Add(BlogEntry entry, IEnumerable<string> tags);

		/// <summary>
		/// Updates the given <see cref="BlogEntry"/>.
		/// </summary>
		/// <param name="entry">The <see cref="BlogEntry"/> to update.</param>
		/// <param name="tags">The tags.</param>
		void Update(BlogEntry entry, IEnumerable<string> tags);

		/// <summary>
		/// Adds the file to the <see cref="BlogEntry"/> with the given Id.
		/// </summary>
		/// <param name="id">The id.</param>
		/// <param name="fileName">The filename.</param>
		/// <param name="file">The file.</param>
		void AddFile(Guid id, string fileName, byte[] file);
    }
}