﻿using System;
using System.Collections.Generic;
using System.Linq;
using MVCBlog.Core.Entities;
using MVCBlog.Core.Repository;

namespace MVCBlog.Core.Service
{
    /// <summary>
	/// Access to <see cref="Image">Images</see>.
    /// </summary>
	public class ImageService : GenericEntityService<Image>, IImageService
    {
		/// <summary>
		/// Returns an <see cref="IEnumerable{T}"/> from the <see cref="MVCBlog.Core.Repository.IGenericRepository{T}"/>.
		/// </summary>
		/// <returns>
		/// The <see cref="IEnumerable{T}"/> of all elements.
		/// </returns>
		public override IEnumerable<Image> GetAll()
		{
			return this.Repository.GetQuery().OrderByDescending(i => i.Created);
		}

        /// <summary>
        /// Adds an <see cref="Image"/>.
        /// </summary>
        /// <param name="fileName">The filename.</param>
        /// <param name="file">The file.</param>
        public void Add(string fileName, byte[] file)
        {
            if (fileName == null)
			{
				throw new ArgumentNullException("fileName");
			}

			if (file == null)
			{
				throw new ArgumentNullException("file");
			}

            int indexOfLastDot = fileName.LastIndexOf('.');
            string name = fileName.Substring(0, indexOfLastDot);
            string extension = fileName.Substring(indexOfLastDot + 1, fileName.Length - indexOfLastDot - 1);

            var image = new MVCBlog.Core.Entities.Image() { Name = name, Extension = extension };
            image.Data = file;

            this.Repository.Add(image);

            UnitOfWork.Commit();
        }

		/// <summary>
		/// Deletes the given element from the <see cref="IGenericRepository{T}"/>.
		/// </summary>
		/// <param name="entity">Das zu löschende Element.</param>
		public override void Delete(Image entity)
		{
			if (entity == null)
			{
				throw new ArgumentNullException("entity");
			}
			
			entity.DeleteData();
			base.Delete(entity);
		}
    }
}
