﻿using System;
using System.Collections.Generic;
using System.Linq;
using MVCBlog.Core.Entities;

namespace MVCBlog.Core.Service
{
    /// <summary>
	/// Access to <see cref="Tag">Tags</see>.
    /// </summary>
	public class TagService : GenericEntityService<Tag>, ITagService
    {
		/// <summary>
		/// Gets the <see cref="Tag"/> with the given text.
		/// </summary>
		/// <param name="text">The text.</param>
		/// <returns>
		/// The <see cref="Tag"/> with the given text.
		/// </returns>
		public Tag GetByText(string text)
		{
			if (text == null)
			{
				throw new ArgumentNullException("text");
			}

			return this.Repository.SingleOrDefault(t => t.Name.Equals(text, StringComparison.OrdinalIgnoreCase));
		}		

		/// <summary>
		/// Returns an <see cref="IEnumerable{T}"/> from the <see cref="MVCBlog.Core.Repository.IGenericRepository{T}"/>.
		/// </summary>
		/// <returns>
		/// The <see cref="IEnumerable{T}"/> of all elements.
		/// </returns>
		public override IEnumerable<Tag> GetAll()
		{
			return this.Repository.GetQuery().OrderBy(t => t.Name);
		}
	}
}
