﻿using System.Web.Mvc;
using System.Web.Routing;
using log4net;
using MVCBlog.Website.Controllers;

namespace MVCBlog.Website
{
	/// <summary>
	/// Defines the methods, properties, and events in this ASP.NET application.
	/// </summary>
	public class MvcApplication : System.Web.HttpApplication
	{
        /// <summary>
        /// Logger instance.
        /// </summary>
        private static readonly ILog logger = LogManager.GetLogger(typeof(MvcApplication));

        /// <summary>
        /// Registers the routes.
        /// </summary>
        /// <param name="routes">The routes.</param>
        public static void RegisterRoutes(RouteCollection routes)
        {
            routes.IgnoreRoute("{resource}.axd/{*pathInfo}");
            routes.IgnoreRoute("{*favicon}", new { favicon = @"(.*/)?favicon.ico(/.*)?" });

            // Short URL for '404'
            routes.MapRoute(
                "Short_404",
                "404",
                new { controller = MVC.Error.Name, action = MVC.Error.Actions.NotFound });

            routes.MapRoute(
                "BlogEntry",
                MVC.Blog.Name + "/{year}/{month}/{day}/{id}",
                new { controller = MVC.Blog.Name, action = MVC.Blog.Actions.Entry },
                new { year = "\\d{4}", month = "\\d{1,2}", day = "\\d{1,2}", id = ".+" });

            routes.MapRoute(
               "Tag",
               MVC.Blog.Name + "/Tag/{tag}",
               new { controller = MVC.Blog.Name, action = MVC.Blog.Actions.Index },
               new { tag = ".+" });

            routes.MapRoute(
               "TagPaging",
               MVC.Blog.Name + "/Tag/{tag}/Page/{page}",
               new { controller = MVC.Blog.Name, action = MVC.Blog.Actions.Index },
               new { tag = ".+", page = "\\d+" });

            routes.MapRoute(
               "BlogPaging",
               MVC.Blog.Name + "/Page/{page}",
               new { controller = MVC.Blog.Name, action = MVC.Blog.Actions.Index },
               new { page = "\\d+" });

            routes.MapRoute(
                "Default",
                "{controller}/{action}/{id}",
                new { controller = MVC.Blog.Name, action = MVC.Blog.Actions.Index, id = string.Empty });
        }

        /// <summary>
        /// Executed when the ASP.NET application starts.
        /// </summary>
		protected void Application_Start()
		{
			// Init logger
			log4net.Config.XmlConfigurator.Configure();

            ControllerBuilder.Current.SetControllerFactory(new IocControllerFactory());  

			ViewEngines.Engines.Clear();
            ViewEngines.Engines.Add(new Palmmedia.Common.Net.Mvc.Localization.LocalizationWebFormViewEngine());

			RegisterRoutes(RouteTable.Routes);

			logger.Debug("Application started.");
		}
	}
}